# Provo River near Woodland, UT (single offset)

## USGS Gage ID: 10154200

## Control
The channel is fairly straight for about 300 feet above and 30 feet below gage where it starts to bend left.
The streambed is composed of rounded cobbles and boulders, and the gradient is fairly steep in the vicinity of the gage.
The low to medium flow control is a rocky riffle about 80 feet below the gage, and during high flow channel geometry becomes the control.
Both banks are rather rocky with a slope of about 45 degrees and are generally not subject to overflow.
Both section and channel controls present, but due to channel roughness and slope a single straight-line rating segment (single offset) represents the stage discharge relation for both controls.
This is common in high gradient cobble or larger substrate streams.

## Stage Ranges
- Reach control: 
- Channel control: